OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Impossibile scrivere nella cartella \"config\".",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\"",
    "See %s" : "Vedere %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ciò può essere normalmente corretto %sfornendo al server web accesso in scrittura alla cartella \"config\"%s",
    "Sample configuration detected" : "Configurazione di esempio rilevata",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
    "PHP %s or higher is required." : "Richiesto PHP %s o superiore",
    "PHP with a version lower than %s is required." : "Richiesta una versione di PHP minore di %s.",
    "%sbit or higher PHP required." : "Richiesto PHP %sbit o superiore.",
    "Following databases are supported: %s" : "I seguenti database sono supportati: %s",
    "The command line tool %s could not be found" : "Lo strumento da riga di comando %s non è stato trovato",
    "The library %s is not available." : "La libreria %s non è disponibile.",
    "Library %s with a version higher than %s is required - available version %s." : "Richiesta una versione della libreria %s maggiore di %s - versione disponibile %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Richiesta una versione della libreria %s minore di %s - versione disponibile %s.",
    "Following platforms are supported: %s" : "Sono supportate le seguenti piattaforme: %s",
    "ownCloud %s or higher is required." : "Richiesto ownCloud %s o superiore.",
    "ownCloud %s or lower is required." : "Richiesto ownCloud %s o inferiore.",
    "Unknown filetype" : "Tipo di file sconosciuto",
    "Invalid image" : "Immagine non valida",
    "Avatar image is not square" : "L'immagine dell'avatar non è quadrata",
    "today" : "oggi",
    "yesterday" : "ieri",
    "_%n day ago_::_%n days ago_" : ["%d giorno fa","%n giorni fa"],
    "last month" : "mese scorso",
    "_%n month ago_::_%n months ago_" : ["%n mese fa","%n mesi fa"],
    "last year" : "anno scorso",
    "_%n year ago_::_%n years ago_" : ["%n anno fa","%n anni fa"],
    "_%n hour ago_::_%n hours ago_" : ["%n ora fa","%n ore fa"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuto fa","%n minuti fa"],
    "seconds ago" : "secondi fa",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Il modulo con id: %s non esiste. Abilitalo nelle impostazioni delle applicazioni o contatta il tuo amministratore.",
    "Builtin" : "Integrata",
    "None" : "Nessuno",
    "Username and password" : "Nome utente e password",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Log-in credentials, save in session" : "Credenziali di accesso, salva nella sessione",
    "Empty filename is not allowed" : "Un nome di file vuoto non è consentito",
    "Dot files are not allowed" : "I file con un punto iniziale non sono consentiti",
    "4-byte characters are not supported in file names" : "I caratteri di 4 byte non sono supportati nei nomi dei file",
    "File name is a reserved word" : "Il nome del file è una parola riservata",
    "File name contains at least one invalid character" : "Il nome del file contiene almeno un carattere non valido",
    "File name is too long" : "Il nome del file è troppo lungo",
    "App directory already exists" : "La cartella dell'applicazione esiste già",
    "Can't create app folder. Please fix permissions. %s" : "Impossibile creare la cartella dell'applicazione. Correggi i permessi. %s",
    "Archive does not contain a directory named %s" : "L'archivio non contiene una cartella con nome %s",
    "No source specified when installing app" : "Nessuna fonte specificata durante l'installazione dell'applicazione",
    "No href specified when installing app from http" : "Nessun href specificato durante l'installazione dell'applicazione da http",
    "No path specified when installing app from local file" : "Nessun percorso specificato durante l'installazione dell'applicazione da file locale",
    "Archives of type %s are not supported" : "Gli archivi di tipo %s non sono supportati",
    "Failed to open archive when installing app" : "Apertura archivio non riuscita durante l'installazione dell'applicazione",
    "App does not provide an info.xml file" : "L'applicazione non fornisce un file info.xml",
    "App cannot be installed because appinfo file cannot be read." : "L'applicazione non può essere installata poiché il file appinfo non può essere letto.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La firma non può essere verificata. Contatta lo sviluppatore dell'applicazione e controlla la schermata di amministrazione.",
    "App can't be installed because of not allowed code in the App" : "L'applicazione non può essere installata a causa di codice non consentito al suo interno",
    "App can't be installed because it is not compatible with this version of ownCloud" : "L'applicazione non può essere installata poiché non è compatibile con questa versione di ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'applicazione non può essere installata poiché contiene il tag <shipped>true<shipped> che è consentito per le applicazioni native",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'applicazione non può essere installata poiché la versione nel file info.xml non è la stessa riportata dall'app store",
    "Apps" : "Applicazioni",
    "General" : "Generale",
    "Storage" : "Archiviazione",
    "Security" : "Protezione",
    "Encryption" : "Cifratura",
    "Workflows & Tags" : "Flussi di Lavoro & Etichette",
    "Sharing" : "Condivisione",
    "Search" : "Cerca",
    "Updates" : "Aggiornamenti",
    "Help & Tips" : "Aiuto e suggerimenti",
    "Additional" : "Aggiuntivo",
    "%s enter the database username and name." : "%s digita il nome utente e il nome del database.",
    "%s enter the database username." : "%s digita il nome utente del database.",
    "%s enter the database name." : "%s digita il nome del database.",
    "%s you may not use dots in the database name" : "%s non dovresti utilizzare punti nel nome del database",
    "Oracle connection could not be established" : "La connessione a Oracle non può essere stabilita",
    "Oracle username and/or password not valid" : "Nome utente e/o password di Oracle non validi",
    "DB Error: \"%s\"" : "Errore DB: \"%s\"",
    "Offending command was: \"%s\"" : "Il comando non consentito era: \"%s\"",
    "You need to enter either an existing account or the administrator." : "È necessario inserire un account esistente o l'amministratore.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Il comando non consentito era: \"%s\", nome: %s, password: %s",
    "PostgreSQL username and/or password not valid" : "Nome utente e/o password di PostgreSQL non validi",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non è supportato e %s non funzionerà correttamente su questa piattaforma. Usalo a tuo rischio!",
    "For the best results, please consider using a GNU/Linux server instead." : "Per avere il risultato migliore, prendi in considerazione l'utilizzo di un server GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembra che questa istanza di %s sia in esecuzione in un ambiente PHP a 32 bit e che open_basedir sia stata configurata in php.ini. Ciò comporterà problemi con i file più grandi di 4 GB ed è altamente sconsigliato.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Rimuovi l'impostazione di open_basedir nel tuo php.ini o passa alla versione a 64 bit di PHP.",
    "Set an admin username." : "Imposta un nome utente di amministrazione.",
    "Set an admin password." : "Imposta una password di amministrazione.",
    "Can't create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
    "%s shared »%s« with you" : "%s ha condiviso «%s» con te",
    "%s via %s" : "%s tramite %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Condivisione di %s non riuscita, poiché il motore non consente condivisioni del tipo %i",
    "Sharing %s failed, because the file does not exist" : "Condivisione di %s non riuscita, poiché il file non esiste",
    "You are not allowed to share %s" : "Non ti è consentito condividere %s",
    "Sharing %s failed, because you can not share with yourself" : "Condivisione di %s non riuscita, poiché non puoi condividere con te stesso",
    "Sharing %s failed, because the user %s does not exist" : "Condivisione di %s non riuscita, poiché l'utente %s non esiste",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Condivisione di %s non riuscita, poiché l'utente %s non appartiene ad alcun gruppo di cui %s è membro",
    "Sharing %s failed, because this item is already shared with %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con l'utente %s",
    "Sharing %s failed, because the group %s does not exist" : "Condivisione di %s non riuscita, poiché il gruppo %s non esiste",
    "Sharing %s failed, because %s is not a member of the group %s" : "Condivisione di %s non riuscita, poiché %s non appartiene al gruppo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Devi fornire una password per creare un collegamento pubblico, sono consentiti solo i collegamenti protetti",
    "Sharing %s failed, because sharing with links is not allowed" : "Condivisione di %s non riuscita, poiché i collegamenti non sono consentiti",
    "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La condivisione di %s non è riuscita, impossibile trovare %s, è probabile che il server non sia al momento raggiungibile.",
    "Share type %s is not valid for %s" : "Il tipo di condivisione %s non è valido per %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Impostazione permessi per %s non riuscita, poiché i permessi superano i permessi accordati a %s",
    "Setting permissions for %s failed, because the item was not found" : "Impostazione permessi per %s non riuscita, poiché l'elemento non è stato trovato",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossibile impostare la data di scadenza. Le condivisioni non possono scadere più tardi di %s dalla loro attivazione",
    "Cannot set expiration date. Expiration date is in the past" : "Impossibile impostare la data di scadenza. La data di scadenza è nel passato.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Impossibile cancellare la data di scadenza. Le condivisioni devono avere una data di scadenza.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Il motore di condivisione %s deve implementare l'interfaccia OCP\\Share_Backend",
    "Sharing backend %s not found" : "Motore di condivisione %s non trovato",
    "Sharing backend for %s not found" : "Motore di condivisione di %s non trovato",
    "Sharing failed, because the user %s is the original sharer" : "Condivisione non riuscita, poiché l'utente %s ha condiviso in origine",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Condivisione di %s non riuscita, poiché i permessi superano quelli accordati a %s",
    "Sharing %s failed, because resharing is not allowed" : "Condivisione di %s non riuscita, poiché la ri-condivisione non è consentita",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Condivisione di %s non riuscita, poiché il motore di condivisione per %s non riesce a trovare la sua fonte",
    "Sharing %s failed, because the file could not be found in the file cache" : "Condivisione di %s non riuscita, poiché il file non è stato trovato nella cache",
    "Cannot increase permissions of %s" : "Impossibile aumentare i permessi di %s",
    "Files can't be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
    "Files can't be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
    "Expiration date is in the past" : "La data di scadenza è nel passato",
    "Cannot set expiration date more than %s days in the future" : "Impossibile impostare la data di scadenza a più di %s giorni nel futuro",
    "Could not find category \"%s\"" : "Impossibile trovare la categoria \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un nome utente: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
    "A valid username must be provided" : "Deve essere fornito un nome utente valido",
    "Username contains whitespace at the beginning or at the end" : "Il nome utente contiene spazi all'inizio o alla fine",
    "A valid password must be provided" : "Deve essere fornita una password valida",
    "The username is already being used" : "Il nome utente è già utilizzato",
    "Login canceled by app" : "Accesso annullato dall'applicazione",
    "User disabled" : "Utente disabilitato",
    "Help" : "Aiuto",
    "Settings" : "Impostazioni",
    "Users" : "Utenti",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'applicazione \"%s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %s",
    "web services under your control" : "servizi web nelle tue mani",
    "File is currently busy, please try again later" : "Il file è attualmente occupato, riprova più tardi",
    "Can't read file" : "Impossibile leggere il file",
    "Application is not enabled" : "L'applicazione  non è abilitata",
    "Authentication error" : "Errore di autenticazione",
    "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
    "Unknown user" : "Utente sconosciuto",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nessun driver di database (sqlite, mysql o postgresql) installato",
    "Cannot write into \"config\" directory" : "Impossibile scrivere nella cartella \"config\"",
    "Cannot write into \"apps\" directory" : "Impossibile scrivere nella cartella \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ciò può essere normalmente corretto %sfornendo al server web accesso in scrittura alla cartella \"apps\"%s o disabilitando il negozio di applicazioni nel file di configurazione.",
    "Cannot create \"data\" directory" : "Impossibile creare la cartella \"data\"",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Ciò può essere normalmente corretto <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">fornendo al server web accesso in scrittura alla cartella radice</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "I permessi possono essere normalmente corretti %sfornendo al server web accesso in scrittura alla cartella radice%s.",
    "Setting locale to %s failed" : "L'impostazione della localizzazione a %s non è riuscita",
    "Please install one of these locales on your system and restart your webserver." : "Installa una delle seguenti localizzazioni sul tuo sistema e riavvia il server web.",
    "Please ask your server administrator to install the module." : "Chiedi all'amministratore del tuo server di installare il modulo.",
    "PHP module %s not installed." : "Il modulo PHP %s non è installato.",
    "PHP setting \"%s\" is not set to \"%s\"." : "L'impostazione \"%s\" di PHP non è configurata a \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "La modifica di questa impostazione nel file php.ini permetterà nuovamente l'esecuzione di ownCloud",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload è impostata a \"%s\" invece del valore atteso \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Per correggere questo problema, imposta <code>mbstring.func_overload</code> a <code>0</code> nel tuo php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "È richiesta almeno la versione 2.7.0 di libxml2. Quella attualmente installata è la %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Per risolvere questo problema, aggiorna la tua versione di libxml2 e riavvia il server web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Sono stati installati moduli PHP, ma sono elencati ancora come mancanti?",
    "Please ask your server administrator to restart the web server." : "Chiedi all'amministratore di riavviare il server web.",
    "PostgreSQL >= 9 required" : "Richiesto PostgreSQL >= 9",
    "Please upgrade your database version" : "Aggiorna la versione del tuo database",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dagli altri utenti.",
    "Your Data directory is readable by other users" : "La tua cartella dei dati è leggibile dagli altri utenti",
    "Your Data directory must be an absolute path" : "La cartella dei dati deve essere un percorso assoluto",
    "Check the value of \"datadirectory\" in your configuration" : "Controlla il valore di \"datadirectory\" nella tua configurazione",
    "Your Data directory  is invalid" : "La tua cartella dei dati non è valida",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Verifica che la cartella dei dati contenga un file \".ocdata\" nella sua radice.",
    "Could not obtain lock type %d on \"%s\"." : "Impossibile ottenere il blocco di tipo %d su \"%s\".",
    "Storage unauthorized. %s" : "Archiviazione non autorizzata. %s",
    "Storage incomplete configuration. %s" : "Configurazione dell'archiviazione incompleta.%s",
    "Storage connection error. %s" : "Errore di connessione all'archiviazione. %s",
    "Storage is temporarily not available" : "L'archiviazione non è temporaneamente disponibile",
    "Storage connection timeout. %s" : "Timeout di connessione all'archiviazione. %s",
    "A safe home for all your data" : "Una casa sicura per tutti i tuoi dati",
    "User Authentication" : "Autenticazione utente",
    "File cannot be read" : "Il File non può essere letto",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s non è supportato e %s non potrà funzionare su questa piattaforma. Utilizzalo a tuo rischio !",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "Errore nella condivisione di %s, non trovo %s, verifica come scritto e la disponibilità del server.",
    "The username must be at least 3 characters long" : "Il nome utente deve essere lungo almeno  tre caratteri",
    "Imprint" : "Imprint",
    "__language_name__" : "Italiano"
},
"nplurals=2; plural=(n != 1);");
